
clustergrammer_widget2
=====================================

Version: |release|

A Custom Jupyter Widget Library


Quickstart
----------

To get started with clustergrammer_widget2, install with pip::

    pip install clustergrammer_widget2

or with conda::

    conda install clustergrammer_widget2


Contents
--------

.. toctree::
   :maxdepth: 2
   :caption: Installation and usage

   installing
   introduction

.. toctree::
   :maxdepth: 1

   examples/index


.. toctree::
   :maxdepth: 2
   :caption: Development

   develop-install


.. links

.. _`Jupyter widgets`: https://jupyter.org/widgets.html

.. _`notebook`: https://jupyter-notebook.readthedocs.io/en/latest/
